====================
Main Classes
====================

NodeSet
---------

.. autoclass:: graphio.NodeSet
    :members:

RelationshipSet
-----------------

.. autoclass:: graphio.RelationshipSet
    :members:

Container
---------

.. autoclass:: graphio.Container
    :members: